﻿using System;
using System.IO;
using System.Text;

namespace Inedo.Agents.Service
{
    internal static class Log
    {
        private static Lazy<TextWriter> logFile = new Lazy<TextWriter>(OpenLogFile);
        private static readonly object logLock = new object();

        public static void Debug(string message)
        {
            if (string.IsNullOrWhiteSpace(message))
                return;

            lock (logLock)
            {
                logFile.Value.WriteLine(DateTime.Now + " DEBUG: " + message);
            }
        }
        public static void Info(string message)
        {
            if (string.IsNullOrWhiteSpace(message))
                return;

            lock (logLock)
            {
                Console.WriteLine(message);
                logFile.Value.WriteLine(DateTime.Now + ": " + message);
            }
        }
        public static void Error(string message)
        {
            if (string.IsNullOrWhiteSpace(message))
                return;

            lock (logLock)
            {
                Console.Error.WriteLine(message);
                logFile.Value.WriteLine(DateTime.Now + " ERROR: " + message);
            }
        }

        private static TextWriter OpenLogFile()
        {
            try
            {
                var fileName = AgentConfig.LogFile;
                if (!string.IsNullOrWhiteSpace(fileName))
                {
                    return new StreamWriter(new FileStream(fileName, FileMode.Append, FileAccess.Write, FileShare.ReadWrite), new UTF8Encoding(false))
                    {
                        AutoFlush = true
                    };
                }
            }
            catch
            {
            }

            return TextWriter.Null;
        }
    }
}
